@@ -1,6 +1,6 @@
 /*
  * format.c: Output format definitions for sadf
- * (C) 2011-2015 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 2011-2014 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -94,6 +94,19 @@ struct report_format json_fmt = {
 	.f_comment	= print_json_comment
 };
 
+/*
+ * Display only datafile header.
+ */
+struct report_format conv_fmt = {
+	.id		= F_CONV_OUTPUT,
+	.options	= FO_BAD_FILE_FORMAT,
+	.f_header	= NULL,
+	.f_statistics	= NULL,
+	.f_timestamp	= NULL,
+	.f_restart	= NULL,
+	.f_comment	= NULL
+};
+
 /*
  * Array of output formats.
  */
@@ -102,5 +115,6 @@ struct report_format *fmt[NR_FMT] = {
 	&db_fmt,
 	&ppc_fmt,
 	&xml_fmt,
-	&json_fmt
+	&json_fmt,
+	&conv_fmt
 };
