@@ -1,6 +1,6 @@
 /*
  * sadc: system activity data collector
- * (C) 1999-2015 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2014 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -236,10 +236,8 @@ void alarm_handler(int sig)
  */
 void int_handler(int sig)
 {
-	pid_t ppid = getppid();
-
-	if (!optz || (ppid == 1)) {
-		/* sadc hasn't been called by sar or sar process is already dead */
+	if (!optz) {
+		/* sadc hasn't been called by sar */
 		exit(1);
 	}
 
@@ -248,7 +246,7 @@ void int_handler(int sig)
 	 * by sadc, not sar. So send SIGINT to sar so that average stats
 	 * can be displayed.
 	 */
-	if (kill(ppid, SIGINT) < 0) {
+	if (kill(getppid(), SIGINT) < 0) {
 		exit(1);
 	}
 }
@@ -436,38 +434,14 @@ int ask_for_flock(int fd, int fatal)
  */
 void fill_magic_header(struct file_magic *file_magic)
 {
-	char *v;
-	char version[16];
-
 	memset(file_magic, 0, FILE_MAGIC_SIZE);
 
 	file_magic->header_size = FILE_HEADER_SIZE;
 
 	file_magic->sysstat_magic = SYSSTAT_MAGIC;
 	file_magic->format_magic  = FORMAT_MAGIC;
-	file_magic->sysstat_extraversion = 0;
 
-	strcpy(version, VERSION);
-
-	/* Get version number */
-	if ((v = strtok(version, ".")) == NULL)
-		return;
-	file_magic->sysstat_version = atoi(v) & 0xff;
-
-	/* Get patchlevel number */
-	if ((v = strtok(NULL, ".")) == NULL)
-		return;
-	file_magic->sysstat_patchlevel = atoi(v) & 0xff;
-
-	/* Get sublevel number */
-	if ((v = strtok(NULL, ".")) == NULL)
-		return;
-	file_magic->sysstat_sublevel = atoi(v) & 0xff;
-
-	/* Get extraversion number. Don't necessarily exist */
-	if ((v = strtok(NULL, ".")) == NULL)
-		return;
-	file_magic->sysstat_extraversion = atoi(v) & 0xff;
+	enum_version_nr(file_magic);
 }
 
 /*
