@@ -87,7 +87,7 @@ void usage(char *progname)
 		progname);
 
 	fprintf(stderr, _("Options are:\n"
-			  "[ -C ] [ -d | -j | -p | -x ] [ -H ] [ -h ] [ -T | -t | -U ] [ -V ]\n"
+			  "[ -C ] [ -c | -d | -j | -p | -x ] [ -H ] [ -h ] [ -T | -t | -U ] [ -V ]\n"
 			  "[ -P { <cpu> [,...] | ALL } ] [ -s [ <hh:mm:ss> ] ] [ -e [ <hh:mm:ss> ] ]\n"
 			  "[ -- <sar_options> ]\n"));
 	exit(1);
@@ -546,7 +546,6 @@ void write_mech_stats(int curr, unsigned long dt, unsigned long long itv,
  * 			been used or not) can be saved for current record.
  * @loctime		Structure where timestamp (expressed in local time)
  *			can be saved for current record.
- * @reset_cd		TRUE if static cross_day variable should be reset.
  *
  * OUT:
  * @cnt			Set to 0 to indicate that no other lines of stats
@@ -558,21 +557,12 @@ void write_mech_stats(int curr, unsigned long dt, unsigned long long itv,
  */
 int write_parsable_stats(int curr, int reset, long *cnt, int use_tm_start,
 			 int use_tm_end, unsigned int act_id, __nr_t cpu_nr,
-			 struct tm *rectime, struct tm *loctime, int reset_cd)
+			 struct tm *rectime, struct tm *loctime)
 {
 	unsigned long long dt, itv, g_itv;
 	char cur_date[32], cur_time[32];
 	static int cross_day = FALSE;
 
-	if (reset_cd) {
-		/*
-		 * See note in sar.c.
-		 * NB: Reseting cross_day is not needed in write_textual_stats()
-		 * function (datafile is never rewinded).
-		 */
-		cross_day = 0;
-	}
-
 	/*
 	 * Check time (1).
 	 * For this first check, we use the time interval entered on
@@ -881,7 +871,7 @@ void rw_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf,
 			char *file, struct file_magic *file_magic)
 {
 	unsigned char rtype;
-	int next, reset_cd;
+	int next;
 
 	if (lseek(ifd, fpos, SEEK_SET) < fpos) {
 		perror("lseek");
@@ -900,7 +890,6 @@ void rw_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf,
 	copy_structures(act, id_seq, record_hdr, !*curr, 2);
 
 	*cnt  = count;
-	reset_cd = 1;
 
 	do {
 		/* Display <count> lines of stats */
@@ -925,8 +914,7 @@ void rw_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf,
 
 			next = write_parsable_stats(*curr, *reset, cnt,
 						    tm_start.use, tm_end.use, act_id,
-						    cpu_nr, rectime, loctime, reset_cd);
-			reset_cd = 0;
+						    cpu_nr, rectime, loctime);
 
 			if (next) {
 				/*
@@ -1605,6 +1593,13 @@ int main(int argc, char **argv)
 						flags |= S_F_COMMENT;
 						break;
 
+					case 'c':
+						if (format) {
+							usage(argv[0]);
+						}
+						format = F_CONV_OUTPUT;
+						break;
+
 					case 'd':
 						if (format) {
 							usage(argv[0]);
@@ -1756,8 +1751,14 @@ int main(int argc, char **argv)
 		interval = 1;
 	}
 
-	/* Read stats from file */
-	read_stats_from_file(dfile);
+	if (format == F_CONV_OUTPUT) {
+		/* Convert file to current format */
+		convert_file(dfile, act);
+	}
+	else {
+		/* Read stats from file */
+		read_stats_from_file(dfile);
+	}
 
 	/* Free bitmaps */
 	free_bitmaps(act);
